pub trait Retrieve {
type Output;
// Required method
fn retrieve(&self) -> Self::Output;
}Expand description
A generalization for numbers kept in optimized representations (e.g. Montgomery) that can be converted back to the original form.
Required Associated Types
Required Methods
Dyn Compatibility
This trait is dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".